@@ -1,7 +1,8 @@
 import fire
 
 from .main import run, activate, deactivate, settings
-from .logger import stream
+from .logger import stream, show_current_data
+from .util import enable_w1
 
 
 fire.Fire({
@@ -12,5 +13,7 @@ fire.Fire({
     'start': activate,
     'deactivate': deactivate,
     'stop': deactivate,
-    'stream': stream
+    'stream': stream,
+    'read-sensors': show_current_data,
+    'enable_w1': enable_w1
 })
